/**
  ******************************************************************************
  * @file           : main.c
  * @author         : SINOMCU-AE
  * @brief          : Main program body
  *    
  *          This file provides example code for Timer1 CCxIF(x:3,4) set test and printf by uart.
  * PWM period 10Hz,CC4 interrupt enable.
  * LED1 Toggle and uart send information of running count(redirect printf),defualt period 0.5S.
  * For details, see "readme.txt"    
  *         
  ******************************************************************************
   * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, SinoMCU shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu All rights reserved.</center></h2>
  *
  ******************************************************************************
  */  
  
#include "system_define.h"

#define COUNT_PERIOD         500       // unit ms

FlagStatus TIMER1_BRK_UP_TRG_COM = RESET;
FlagStatus TIMER1_CC4 = RESET, TIMER1_CC3 = RESET;

/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void) {
  uint32_t count = 0;
    
#if(defined(SYSCLK_USE_PLL_48M) && SYSCLK_USE_PLL_48M) 
  sysclk_init();                  // sysclk 48M,HSI 8M /2*12;if not call this function,default HSI 8M
#endif
  SystemCoreClockUpdate();        //get System Core Clock
    
  sys_tick_init();
  gpio_init();
  timer1_pwm_init();
#if(defined(EN_PRINT_UART) && EN_PRINT_UART)  
  MS32_RCC_SetUSARTClockSource(MS32_RCC_USART1_CLKSOURCE_HSI);  // uart clk HSI 8M  
  usart1_uart_init(115200);
#endif
  LED1_ON(); 
  
  printf("\r\n\r\n*****Timer1 CCxIF Example*****");
  printf("\r\n--Inf:System Core Clock %d Hz.",SystemCoreClock);
    
  Start_User_MS_SF_Timer(COUNT_PERIOD);
  while(1) {
    if(TIMER1_BRK_UP_TRG_COM == SET) {                          // Timer UIE interrupt,defualt 500ms
      TIMER1_BRK_UP_TRG_COM = RESET;  
      printf("\r\n--Inf:Timer1 UIF set.");
    }    
    if(TIMER1_CC4 == SET) {                                    // Timer CC4 interrupt,defualt 100ms(10Hz)
      TIMER1_CC4 = RESET;  
      printf("\r\n--Inf:Timer1 CC4IF set.");
    } 
    if(TIMER1_CC3 == SET) {                                    // Timer CC3 interrupt,defualt 100ms(10Hz)
      TIMER1_CC3 = RESET;  
      printf(",CC3IF set.");
    }
           
    if(Get_State_User_MS_SF_Timer() == SF_TIMER_OV) {
      Start_User_MS_SF_Timer(COUNT_PERIOD);                     // clear soft timer ov
      LED1_TOGGLE();
      count++;
      printf("\r\n--Inf: running count:%d",count);
    }
  }
}

/**
  * @brief  timer1 BRK UP TRG COM interrupt callback function
  * @param  None
  * @retval None
  */
void Timer_BRK_UP_TRG_COM_Callback(void) {
  TIMER1_BRK_UP_TRG_COM = SET;
}

/**
  * @brief  timer1 CC4 interrupt callback function
  * @param  None
  * @retval None
  */
void Timer_CC4_Callback(void) {
  TIMER1_CC4 = SET;
}

/**
  * @brief  timer1 CC3 interrupt callback function
  * @param  None
  * @retval None
  */
void Timer_CC3_Callback(void) {
  TIMER1_CC3 = SET;
}

/**
  * @brief  SystemClock_Config HSI/2 to PLL*12 sysclk 48M
  * @param  None
  * @retval None
  */
void sysclk_init(void) {
  MS32_RCC_OscInitTypeDef osc_cfg;
  MS32_RCC_PllInitTypeDef pll_cfg;
  MS32_RCC_ClkInitTypeDef clk_cfg;

  // get and clear reset flag 
  MS32_RCC_GetResetFlag(ENABLE);
  
  // osc config 
  osc_cfg.HSIState = MS32_RCC_HSI_ON;
  osc_cfg.HSEState = MS32_RCC_HSE_OFF;
  osc_cfg.LSIState = MS32_RCC_LSI_OFF;
//  osc_cfg.LSEState = MS32_RCC_LSE_ON_DRV_H;
  MS32_RCC_OscConfig(&osc_cfg);
  
  // pll config 
  pll_cfg.PLLState  = MS32_RCC_PLL_ON;
  pll_cfg.PLLSource = MS32_RCC_PLL_SOURCE_HSI_DIV_2;            // HSI/2 4M
  pll_cfg.PLLMUL    = MS32_RCC_PLL_MUL12;
  pll_cfg.PREDIV    = MS32_RCC_PLL_PREDIV_DIV1;
  MS32_RCC_PllConfig(&pll_cfg);
  
  // sysclk config 
  clk_cfg.SYSCLKSource   = MS32_RCC_SYSCLK_SOURCE_PLL;
  clk_cfg.AHBCLKDivider  = MS32_RCC_SYSCLK_DIV1;
  clk_cfg.APB1CLKDivider = MS32_RCC_HCLK_DIV1;
  MS32_RCC_ClockConfig(&clk_cfg);
}

/******************************** END OF FILE *********************************/
