/**
  ******************************************************************************
  * @file     TIMER_CFG.c
  * @author   SINOMCU-AE
  * @brief    Timer config
  *    
  *          This file provides functions to Timer1 CC3,4 config:
  *              PA11      --> TIM1_CH4,defualt not out
  *             PWM period 10Hz,defualt CC4 interrupt enable; 
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, SinoMCU shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu All rights reserved.</center></h2>
  *
  ******************************************************************************
  */
    
#include "user_config.h"
#include "TIMER_CFG.h"

/**
  * @brief  Timer1 CH4 PWM Out Pin Initialization
  * @param  None
  * @retval None
  */
/* <4=> CH4 PWM Out */
#if (TIM_CCXIF_TEST ==4 )
void timer1_pwm4_pin_init(void) {
  MS32_GPIO_InitTypeDef GpioInitStruct = {0};
  // PA11      --> TIM1_CH4
  MS32_GPIO_StructInit(&GpioInitStruct); 
  GpioInitStruct.Pin = MS32_GPIO_PIN_11;
  GpioInitStruct.Mode = MS32_GPIO_MODE_ALTERNATE;
  GpioInitStruct.Speed = MS32_GPIO_SPEED_FREQ_HIGH;
  GpioInitStruct.OutputType = MS32_GPIO_OUTPUT_PUSHPULL;
  GpioInitStruct.Pull = MS32_GPIO_PULL_UP;
  GpioInitStruct.Alternate = MS32_GPIO_AF_2;
  MS32_GPIO_Init(GPIOA, &GpioInitStruct);                  // init function had enable clock
}
#endif
/**
  * @brief  Timer3 CH1 PWM Initialization
  * @param  None
  * @retval None
  */
void timer1_pwm_init(void) {
  MS32_TIM_InitTypeDef TimerInitStruct = {0};
  MS32_TIM_OC_InitTypeDef TimerOCInitStruct = {0};
/* <4=> CH4 PWM Out */
#if (TIM_CCXIF_TEST ==4 )
  timer1_pwm4_pin_init();                                // PWM pin set
#endif
  MS32_APB1_GRP2_EnableClock(MS32_APB1_GRP2_PERIPH_TIM17);

  // count up,PWM period 10Hz
  MS32_TIM_StructInit(&TimerInitStruct);
  TimerInitStruct.CounterMode = MS32_TIM_COUNTERMODE_UP;
  TimerInitStruct.Prescaler   = __MS32_TIM_CALC_PSC(SystemCoreClock,1000);     // unit Hz,div sysclk to  CNT clk:1Khz
  TimerInitStruct.Autoreload  = __MS32_TIM_CALC_ARR(SystemCoreClock,TimerInitStruct.Prescaler,10); // unit Hz,10Hz 100ms
  TimerInitStruct.RepetitionCounter = 4;                                       // (500ms/100ms)-1
  TimerInitStruct.ClockDivision     = MS32_TIM_CLOCKDIVISION_DIV1;             // fot tDTS
  MS32_TIM_Init(TIM1, &TimerInitStruct);
  MS32_TIM_EnableARRPreload(TIM1);

  MS32_TIM_OC_StructInit(&TimerOCInitStruct);
  TimerOCInitStruct.OCMode   = MS32_TIM_OCMODE_PWM1;                           // PWM1 mode
  TimerOCInitStruct.CompareValue =  ((( MS32_TIM_GetAutoReload(TIM1) + 1 ) * 25 ) / 100);          // set duty cycle 25%
  MS32_TIM_OC_Init(TIM1, MS32_TIM_CHANNEL_CH4, &TimerOCInitStruct);

  TimerOCInitStruct.CompareValue =  ((( MS32_TIM_GetAutoReload(TIM1) + 1 ) * 75 ) / 100);          // set duty cycle 75%
  MS32_TIM_OC_Init(TIM1, MS32_TIM_CHANNEL_CH3, &TimerOCInitStruct);

#if(defined(ENABLE_TIMER1_CH4) && ENABLE_TIMER1_CH4)  
  MS32_TIM_CC_EnableChannel(TIM1, MS32_TIM_CHANNEL_CH4);                  // enable channel 
#endif
/* <4=> CH4 PWM Out */
#if (TIM_CCXIF_TEST ==4 )
  MS32_TIM_EnableAllOutputs(TIM1);                                        // enable ouput 
#else
  MS32_TIM_ITConfig(TIM1,MS32_TIM_DIER_UIE, 0);       // UIE and CC4IE eanble,Cortex-M0,Priority:0-3
  MS32_TIM_ITConfig(TIM1,MS32_TIM_DIER_CC4IE, 1);     // CC4IE eanble,Cortex-M0,Priority:0-3
#endif
/* <1=> CC3IE Set ,<2=> CH4 Channel Disable*/
#if ((TIM_CCXIF_TEST ==1) ||(TIM_CCXIF_TEST ==2))
  MS32_TIM_ITConfig(TIM1,MS32_TIM_DIER_CC3IE, 2);     // CC3IE eanble,Cortex-M0,Priority:0-3,for test,compare with CC4IF
#endif
  MS32_TIM_EnableCounter(TIM1);                       // start timer
} 

/******************************** END OF FILE *********************************/
